# StrIndent

> Easy to use, mistakes protected lib to make indents in strings easily

``` python
from autoindent import Indent

indent = Indent()

indent.add("Some head strings")
indent.add("Indent is necessary", 2)

print(str(indent))
```

**StrIndent** is a easy to use, mistakes protected lib that makes your routine formatting less complicated
